==> fox0.99_0.99.87.orig.tar.gz: fox-0.99.87/include/FXGLCylinder.h <==
/********************************************************************************
*                                                                               *
*                     O p e n G L   C y l i n d e r    O b j e c t              *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999 by Jeroen van der Zijp.   All Rights Reserved.             *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Library General Public                   *
* License as published by the Free Software Foundation; either                  *
* version 2 of the License, or (at your option) any later version.              *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Library General Public License for more details.                              *
*                                                                               *
* You should have received a copy of the GNU Library General Public             *
* License along with this library; if not, write to the Free                    *
* Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.            *
*********************************************************************************
* $Id: FXGLCylinder.h,v 1.2 1999/09/20 22:12:56 jeroen Exp $                    *
********************************************************************************/
#ifndef FXGLCYLINDER_H
#define FXGLCYLINDER_H


class FXAPI FXGLCylinder : public FXGLShape {
  FXDECLARE(FXGLCylinder)
public:
  FXfloat height;
  FXfloat radius;
protected:
  FXGLCylinder();
  virtual void drawshape(FXGLViewer* viewer);
public:
  FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h=1.0, FXfloat r=1.0);
  FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r,const FXMaterial& mtl);
  virtual void save(FXStream& store) const;
  virtual void load(FXStream& store);
  };

#endif

==> fox0.99_0.99.175.orig.tar.gz: fox-0.99.175/include/FXGLCylinder.h <==
/********************************************************************************
*                                                                               *
*                     O p e n G L   C y l i n d e r    O b j e c t              *
*                                                                               *
*********************************************************************************
* Copyright (C) 1999,2001 by Jeroen van der Zijp.   All Rights Reserved.        *
*********************************************************************************
* This library is free software; you can redistribute it and/or                 *
* modify it under the terms of the GNU Lesser General Public                    *
* License as published by the Free Software Foundation; either                  *
* version 2.1 of the License, or (at your option) any later version.            *
*                                                                               *
* This library is distributed in the hope that it will be useful,               *
* but WITHOUT ANY WARRANTY; without even the implied warranty of                *
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU             *
* Lesser General Public License for more details.                               *
*                                                                               *
* You should have received a copy of the GNU Lesser General Public              *
* License along with this library; if not, write to the Free Software           *
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
*********************************************************************************
* $Id: FXGLCylinder.h,v 1.6 2001/04/25 05:47:37 jeroen Exp $                    *
********************************************************************************/
#ifndef FXGLCYLINDER_H
#define FXGLCYLINDER_H


/// OpenGL Cylinder Object
class FXAPI FXGLCylinder : public FXGLShape {
  FXDECLARE(FXGLCylinder)
public:
  FXfloat height;
  FXfloat radius;
protected:
  FXGLCylinder();
  virtual void drawshape(FXGLViewer* viewer);
public:

  /// Construct with specified origin, height and radius
  FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h=1.0, FXfloat r=1.0);

  /// Construct with specified origin, height, radius and material
  FXGLCylinder(FXfloat x,FXfloat y,FXfloat z,FXfloat h,FXfloat r,const FXMaterial& mtl);

  /// Copy constructor
  FXGLCylinder(const FXGLCylinder& orig);

  /// Copy this object
  virtual FXGLObject* copy();

  /// Save to a stream
  virtual void save(FXStream& store) const;

  /// Load from a stream
  virtual void load(FXStream& store);
  
  virtual ~FXGLCylinder();
  };

#endif
